@@ -203,7 +203,7 @@ standard base 64 alphabet is used.
 def ba2int(__a, signed=False):
     """ba2int(bitarray, /, signed=False) -> int
 
-Convert the given bitarray into an integer.
+Convert the given bitarray to an integer.
 The bit-endianness of the bitarray is respected.
 `signed` indicates whether two's complement is used to represent the integer.
 """
@@ -213,22 +213,18 @@ The bit-endianness of the bitarray is respected.
     if length == 0:
         raise ValueError("non-empty bitarray expected")
 
-    big_endian = bool(__a.endian() == 'big')
-    # for big endian pad leading zeros - for little endian we don't need to
-    # pad trailing zeros, as .tobytes() will treat them as zero
-    if big_endian and length % 8:
-        __a = zeros(8 - length % 8, 'big') + __a
-    b = __a.tobytes()
+    le = bool(__a.endian() == 'little')
+    if length % 8:
+        pad = zeros(8 - length % 8, __a.endian())
+        __a = __a + pad if le else pad + __a
 
     if _is_py2:
-        c = bytearray(b)
-        res = 0
-        j = len(c) - 1 if big_endian else 0
-        for x in c:
-            res |= x << 8 * j
-            j += -1 if big_endian else 1
+        a = bitarray(__a, 'big')
+        if le:
+            a.reverse()
+        res = int(ba2hex(a), 16)
     else: # py3
-        res = int.from_bytes(b, byteorder=__a.endian())
+        res = int.from_bytes(__a.tobytes(), byteorder=__a.endian())
 
     if signed and res >= 1 << (length - 1):
         res -= 1 << length
@@ -274,28 +270,25 @@ and requires `length` to be provided.
                                 "got %d" % (1 << length, __i))
 
     a = bitarray(0, get_default_endian() if endian is None else endian)
-    big_endian = bool(a.endian() == 'big')
+    le = bool(a.endian() == 'little')
     if _is_py2:
-        c = bytearray()
-        while __i:
-            __i, r = divmod(__i, 256)
-            c.append(r)
-        if big_endian:
-            c.reverse()
-        b = bytes(c)
+        s = hex(__i)[2:].rstrip('L')
+        a.extend(hex2ba(s, 'big'))
+        if le:
+            a.reverse()
     else: # py3
         b = __i.to_bytes(bits2bytes(__i.bit_length()), byteorder=a.endian())
+        a.frombytes(b)
 
-    a.frombytes(b)
     if length is None:
-        return strip(a, 'left' if big_endian else 'right')
+        return strip(a, 'right' if le else 'left')
 
     la = len(a)
     if la > length:
-        a = a[-length:] if big_endian else a[:length]
+        a = a[:length] if le else a[-length:]
     if la < length:
         pad = zeros(length - la, endian)
-        a = pad + a if big_endian else a + pad
+        a = a + pad if le else pad + a
     assert len(a) == length
     return a
 
